@@ -3,23 +3,19 @@ Simple token counter for each LLM response.
 """
 
 from prometheus_client import Counter
-from . pricelist import price_list
+import json
 
 from .. schema import TextCompletionResponse, Error
-from .. schema import text_completion_response_queue
-from .. log_level import LogLevel
-from .. base import Consumer
+from .. base import FlowProcessor, ConsumerSpec
 
-module = ".".join(__name__.split(".")[1:-1])
+default_ident = "metering"
 
-default_input_queue = text_completion_response_queue
-default_subscriber = module
-
-
-class Processor(Consumer):
+class Processor(FlowProcessor):
 
     def __init__(self, **params):
 
+        id = params.get("id", default_ident)
+
         if not hasattr(__class__, "input_token_metric"):
             __class__.input_token_metric = Counter(
                 'input_tokens', 'Input token count'
@@ -40,40 +36,61 @@ class Processor(Consumer):
                 'output_cost', 'Output cost'
             )
 
-        input_queue = params.get("input_queue", default_input_queue)
-        subscriber = params.get("subscriber", default_subscriber)
-
         super(Processor, self).__init__(
             **params | {
-                "input_queue": input_queue,
-                "subscriber": subscriber,
-                "input_schema": TextCompletionResponse,
+                "id": id,
             }
         )
 
-    def get_prices(self, prices, modelname):
-        for model in prices["price_list"]:
-            if model["model_name"] == modelname:
-                return model["input_price"], model["output_price"]
+        self.register_config_handler(self.on_cost_config)
+
+        self.register_specification(
+            ConsumerSpec(
+                name = "input",
+                schema = TextCompletionResponse,
+                handler = self.on_message,
+            )
+        )
+
+        self.prices = {}
+
+        self.config_key = "token-costs"
+
+    # Load token costs from the config service
+    async def on_cost_config(self, config, version):
+
+        print("Loading configuration version", version)
+
+        if self.config_key not in config:
+            print(f"No key {self.config_key} in config", flush=True)
+            return
+
+        config = config[self.config_key]
+
+        self.prices = {
+            k: json.loads(v)
+            for k, v in config.items()
+        }
+
+    def get_prices(self, modelname):
+
+        if modelname in self.prices:
+            model = self.prices[modelname]
+            return model["input_price"], model["output_price"]
         return None, None  # Return None if model is not found
 
-    async def handle(self, msg):
+    async def on_message(self, msg, consumer, flow):
 
         v = msg.value()
+
         modelname = v.model
-
-        # Sender-produced ID
-        id = msg.properties()["id"]
-
-        print(f"Handling response {id}...", flush=True)
-
         num_in = v.in_token
         num_out = v.out_token
 
         __class__.input_token_metric.inc(num_in)
         __class__.output_token_metric.inc(num_out)
 
-        model_input_price, model_output_price = self.get_prices(price_list, modelname)
+        model_input_price, model_output_price = self.get_prices(modelname)
 
         if model_input_price == None:
             cost_per_call = f"Model Not Found in Price list"
@@ -92,10 +109,8 @@ class Processor(Consumer):
     @staticmethod
     def add_args(parser):
 
-        Consumer.add_args(
-            parser, default_input_queue, default_subscriber,
-        )
+        FlowProcessor.add_args(parser)
 
 def run():
 
-    Processor.launch(module, __doc__)
+    Processor.launch(default_ident, __doc__)
