@@ -9,31 +9,21 @@ import json
 from prometheus_client import Histogram
 import os
 
-from .... schema import TextCompletionRequest, TextCompletionResponse, Error
-from .... schema import text_completion_request_queue
-from .... schema import text_completion_response_queue
-from .... log_level import LogLevel
-from .... base import ConsumerProducer
 from .... exceptions import TooManyRequests
+from .... base import LlmService, LlmResult
 
-module = ".".join(__name__.split(".")[1:-1])
+default_ident = "text-completion"
 
-default_input_queue = text_completion_request_queue
-default_output_queue = text_completion_response_queue
-default_subscriber = module
 default_temperature = 0.0
 default_max_output = 4192
 default_model = "AzureAI"
 default_endpoint = os.getenv("AZURE_ENDPOINT")
 default_token = os.getenv("AZURE_TOKEN")
 
-class Processor(ConsumerProducer):
+class Processor(LlmService):
 
     def __init__(self, **params):
 
-        input_queue = params.get("input_queue", default_input_queue)
-        output_queue = params.get("output_queue", default_output_queue)
-        subscriber = params.get("subscriber", default_subscriber)
         endpoint = params.get("endpoint", default_endpoint)
         token = params.get("token", default_token)
         temperature = params.get("temperature", default_temperature)
@@ -48,30 +38,13 @@ class Processor(ConsumerProducer):
 
         super(Processor, self).__init__(
             **params | {
-                "input_queue": input_queue,
-                "output_queue": output_queue,
-                "subscriber": subscriber,
-                "input_schema": TextCompletionRequest,
-                "output_schema": TextCompletionResponse,
+                "endpoint": endpoint,
                 "temperature": temperature,
                 "max_output": max_output,
                 "model": model,
             }
         )
 
-        if not hasattr(__class__, "text_completion_metric"):
-            __class__.text_completion_metric = Histogram(
-                'text_completion_duration',
-                'Text completion duration (seconds)',
-                buckets=[
-                    0.25, 0.5, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0,
-                    8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0,
-                    17.0, 18.0, 19.0, 20.0, 21.0, 22.0, 23.0, 24.0, 25.0,
-                    30.0, 35.0, 40.0, 45.0, 50.0, 60.0, 80.0, 100.0,
-                    120.0
-                ]
-            )
-
         self.endpoint = endpoint
         self.token = token
         self.temperature = temperature
@@ -123,25 +96,16 @@ class Processor(ConsumerProducer):
 
         return result
 
-    async def handle(self, msg):
-
-        v = msg.value()
-
-        # Sender-produced ID
-
-        id = msg.properties()["id"]
-
-        print(f"Handling prompt {id}...", flush=True)
+    async def generate_content(self, system, prompt):
 
         try:
 
             prompt = self.build_prompt(
-                v.system,
-                v.prompt
+                system,
+                prompt
             )
 
-            with __class__.text_completion_metric.time():
-                response = self.call_llm(prompt)
+            response = self.call_llm(prompt)
 
             resp = response['choices'][0]['message']['content']
             inputtokens = response['usage']['prompt_tokens']
@@ -153,8 +117,14 @@ class Processor(ConsumerProducer):
 
             print("Send response...", flush=True)
 
-            r = TextCompletionResponse(response=resp, error=None, in_token=inputtokens, out_token=outputtokens, model=self.model)
-            await self.send(r, properties={"id": id})
+            resp = LlmResult(
+                text = resp,
+                in_token = inputtokens,
+                out_token = outputtokens,
+                model = self.model
+            )
+
+            return resp
 
         except TooManyRequests:
 
@@ -168,33 +138,14 @@ class Processor(ConsumerProducer):
             # Apart from rate limits, treat all exceptions as unrecoverable
 
             print(f"Exception: {e}")
-
-            print("Send error response...", flush=True)
-
-            r = TextCompletionResponse(
-                error=Error(
-                    type = "llm-error",
-                    message = str(e),
-                ),
-                response=None,
-                in_token=None,
-                out_token=None,
-                model=None,
-            )
-
-            await self.send(r, properties={"id": id})
-
-            self.consumer.acknowledge(msg)
+            raise e
 
         print("Done.", flush=True)
 
     @staticmethod
     def add_args(parser):
 
-        ConsumerProducer.add_args(
-            parser, default_input_queue, default_subscriber,
-            default_output_queue,
-        )
+        LlmService.add_args(parser)
 
         parser.add_argument(
             '-e', '--endpoint',
@@ -224,4 +175,4 @@ class Processor(ConsumerProducer):
 
 def run():
     
-    Processor.launch(module, __doc__)
+    Processor.launch(default_ident, __doc__)
